!
!		COMMONS FOR SEA ICE BIOGEOCHEMISTRY
!		===================================
!
!
! z_i_bio       : vertical coordinate of the middle of bio-layers
! deltaz_i_bio  : thickness of the bio-layers
! c_i_bio       : concentration of tracers in the brines
! cbu_i_bio     : bulk concentration of tracers in the ice
! cbub_i_bio    : concentration of tracers in bubbles for bulk ice
! f_bub         : Gas flux to the atmosphere due to gas bubbles
! t_i_bio       : temperature in the ice, interpolated on the bio grid
! s_i_bio       : salinity in the ice, interpolated on the bio grid
! e_i_bio       : relative brine volume, interpolated on the bio grid
! c_w_bio       : concentration of tracer in seawater

      REAL(8), DIMENSION(nlay_bio) ::
     &   z_i_bio,
     &   deltaz_i_bio,
     &   t_i_bio,
     &   s_i_bio,
     &   e_i_bio,
     &   diff_br_bio

      REAL(8), DIMENSION(0:nlay_bio) ::
     &   zb_i_bio

      REAL(8), DIMENSION(ntra_bio_max) ::
     &   cbu_i_nml,
     &   c_w_bio,
     &   ct_i_bio,
     &   ch_bo_bio,
     &   ch_si_bio,
     &   c_s_bio,
     &   f_su_tra,
     &   f_bo_tra,
     &   f_bogr,
     &   f_sigr,
     &   fcb,
     &   fcbp,
     &   fcsi,
     &   fcbm,
     &   fcsu,
     &   fcb_max,
     &   fgas, 
     &   gas_trvel,
     &   f_bub,
     &   dmol_gas,
     &   mixr_gas

      INTEGER, DIMENSION(ntra_bio_max) ::
     &   nn_init      !: switch for init ( 0=from code, 1=conc. conserved, 2=stock conserved, 3=read profile )

      INTEGER ::
     &   jn_dsi,      !: tracer number for dsi
     &   jn_din,      !:  ...
     &   jn_dip,      !:  ...
     &   jn_aoc,      !:  ...
     &   jn_eoc,      !:  ...
     &   jn_dic,      !:  ...
     &   jn_alk,      !:  ...
     &   jn_ika,      !:  ...
     &   jn_oxy,      !:  ...
     &   jn_arg,      !:  ...
     &   jn_pco,      !:  ...
     &   jn_car,      !:  ...
     &   jn_co2,      !:  ...
     &   jn_cal

      REAL(8), DIMENSION(ntra_bio_max,nlay_bio) ::
     &   c_i_bio,
     &   cbu_i_bio,
     &   cbub_i_bio,
     &   c_gtot_i,
     &   pc_sat,
     &   diag_divf_bio,
     &   csat_gas,
     &   sol_gas

      REAL(8), DIMENSION(ntra_bio_max,0:nlay_bio) ::
     &   fdiff

      COMMON /bioarrays/
     &   z_i_bio,
     &   zb_i_bio,
     &   deltaz_i_bio,
     &   t_i_bio,
     &   s_i_bio,
     &   e_i_bio,
     &   diff_br_bio,
     &   ct_i_bio,
     &   cbu_i_nml,
     &   c_w_bio,
     &   ch_bo_bio,
     &   ch_si_bio,
     &   c_s_bio,
     &   f_su_tra,
     &   f_bo_tra,
     &   f_bogr,
     &   f_sigr,
     &   fcb,
     &   fcbp,
     &   fcsi,
     &   fcbm,
     &   fcsu,
     &   fcb_max,
     &   fgas,
     &   f_bub, 
     &   dmol_gas,
     &   mixr_gas,
     &   gas_trvel,
     &   c_i_bio,
     &   cbu_i_bio,
     &   cbub_i_bio,
     &   c_gtot_i,
     &   pc_sat,
     &   diag_divf_bio,
     &   fdiff,
     &   csat_gas,
     &   sol_gas

      COMMON /bioini/
     &   nn_init                  !: type of initialization for bgc tracers

      COMMON/biotrindex/
     &   jn_dsi,      !: tracer number for dsi
     &   jn_din,      !:  ...
     &   jn_dip,      !:  ...
     &   jn_aoc,      !:  ...
     &   jn_eoc,      !:  ...
     &   jn_dic,      !:  ...
     &   jn_alk,      !:  ...
     &   jn_ika,      !:  ...
     &   jn_oxy,      !:  ...
     &   jn_arg,      !:  ...
     &   jn_pco,      !:  ...
     &   jn_car,      !:  ...
     &   jn_co2,      !:  ...
     &   jn_cal

      COMMON /biophyparams/
     &   nn_bio_opt       ,       !: type of biological formulation
     &   astar_alg        ,       !: specific absorption coeff (m-1 / (mg chla m-3))
     &   fdet_alg         ,       !: fraction of detrital absorption compared to algal absorption
     &   nn_phs           ,       !: type of photosynthesis
     &   nn_lys           ,       !: type of lysis
     &   nn_rem           ,       !: type of remineralization
     &   pp_presc         ,       !: prescribed primary production
     &   h_skel           ,       !: thickness of the biological layer ('SL' & 'BAL' only)
     &   e_thr_bal        ,       !: thickness of the biological layer ('SL' & 'BAL' only)
     &   h_bio            ,       !: thickness of the biological layer ('SL' & 'BAL' only)
     &   brines_ar                !: brines aspect ratio (for gas exchange)

      REAL(8), DIMENSION(ntra_bio_max) ::
     &   mt_i_bio_init, mt_i_bio_final,
     &   mt_w_bio_init, mt_w_bio_final,
     &   mt_i_bio
     
      REAL(8), DIMENSION(ntra_bio_max) ::
     &   mt_i_gas_init, mt_i_gas_final,
     &   mt_i_gas

      REAL(8), DIMENSION(ntra_bio_max) ::
     &   mt_i_carb_init, mt_i_carb_final,
     &   mt_i_carb 

      REAL(8), DIMENSION(ntra_bio_max,nlay_bio) ::
     &   m_i_bio_init, m_i_bio_final


      COMMON/bioconserv/
     &   mt_i_bio_init, mt_i_bio_final,
     &   mt_w_bio_init, mt_w_bio_final,     
     &   mt_i_bio,
     &   mt_i_gas_init, mt_i_gas_final,
     &   mt_i_gas,
     &   mt_i_carb_init, mt_i_carb_final,
     &   mt_i_carb,
     &   m_i_bio_init, m_i_bio_final

      LOGICAL ::
     &   flag_diff(ntra_bio_max)     , !: flag which describes diffusability of a tracer
     &   flag_active(ntra_bio_max)   , !: describe whether a tracer is assumed active or not
     &   flag_adsorb(ntra_bio_max)   , !: adsorbed or not ?
     &   ln_trbo                 , !: activate tracer basal entrapment
     &   ln_trsi                 , !: activate tracer surface entrapment
     &   ln_trdiff               , !: activate tracer diffusion
     &   ln_trremp               , !: activate tracer remapping
     &   ln_lim_dsi              , !: activate DSi limitation
     &   ln_lim_no3              , !: activate NO3 limitation
     &   ln_lim_po4              , !: activate PO4 limitation
     &   ln_lim_lig              , !: activate light limitation
     &   ln_lim_tem              , !: activate temperature inhibition
     &   ln_lim_sal              , !: activate brine salinity inhibition
     &   ln_lys                  , !: activate lysis
     &   ln_rem                  , !: activate remineralization
     &   ln_syn                  , !: activate diatom synthesis
     &   ln_bubform              , !: activate gas buble formation
     &   ln_bubrise              , !: activate gas buble ascent
     &   ln_gasflux              , !: activate gas flux to atm
     &   ln_carbon               , !: activate carbon cycle
     &   ln_ikaite                 !: activate CaCO3 
     
      INTEGER(4) ::
     &   nn_bio_opt              , !: type of biological model (0=NP, 1=NPD Redfield)
     &   nn_diff(ntra_bio_max)   , !: switch for diffusion (0=no diffus, 1=diffus, 2=reset brine cc to zero)
     &   nn_remp(ntra_bio_max)   , !: switch for remapping (0=no remap , 1=diffus. remap, 2=squeeze remap.)
     &   nn_phs                  , !: switch for photosynthesis (1=Ek, 2=chl-C, 3=chl-C+T/S, 4=variable chl-C)
     &   nn_lys                  , !: type of loss term (1=prescribed, 2=T-dependent)
     &   nn_rem                  , !: type of remineralization (1=prescribed, 2=T-dependent)
     &   nn_lim_sal              , !: switch for the type of brine salinity inhibition
     &   ntra_bio                , !: maximum number of tracers
     &   layer_00                , !: index of the first layer
     &   nn_carbonate              !: type of carbonate constants (1=Roy, 2=mehrbach)

      REAL(8) ::
     &   bub_form_rate           ,
     &   bub_diss_rate           ,
     &   h_bl_gas                ,
     &   e_thr_bubrise           ,
     &   e_thr_gasflux           ,
     &   sursat_gas              ,
     &   caco3_time               

      COMMON /bioswi/
     &   flag_diff               ,
     &   flag_active             ,
     &   flag_adsorb             ,
     &   ln_trbo                 ,
     &   ln_trsi                 ,
     &   ln_trdiff               ,
     &   ln_trremp               ,
     &   ln_lim_dsi              ,
     &   ln_lim_no3              ,
     &   ln_lim_po4              ,
     &   ln_lim_lig              ,
     &   ln_lim_tem              ,
     &   ln_lim_sal              ,
     &   ln_lys                  ,
     &   ln_rem                  ,
     &   ln_syn                  ,
     &   nn_diff                 ,
     &   nn_remp                 ,
     &   nn_lim_sal              ,
     &   ntra_bio                ,
     &   layer_00                , 
     &   nn_carbonate            ,
     &   i_gasflux               ,
     &   ln_bubform              ,
     &   ln_bubrise              ,
     &   ln_gasflux              ,
     &   ln_carbon               ,
     &   ln_ikaite               ,
     &   bub_form_rate           ,
     &   bub_diss_rate           ,
     &   h_bl_gas                ,
     &   e_thr_bubrise           ,
     &   e_thr_gasflux           ,
     &   sursat_gas              ,
     &   caco3_time               

      !-----------------------
      ! Brine characteristics
      !-----------------------
      REAL(8), DIMENSION(nlay_bio) ::  ! Brine characteristics
     &   tc_bio                  ,  ! Celsius temperature on the bio-grid
     &   sbr_bio                 ,  ! brine salinity on the bio-grid
     &   rhobr_bio                  ! brine density on the bio-grid

      COMMON/biobrine/
     &   tc_bio                  ,
     &   sbr_bio                 , 
     &   rhobr_bio                 

      !---------------------
      ! Carbonate chemistry
      !---------------------
      REAL(8), DIMENSION(nlay_bio) ::  ! Carbonate chemistry diagnostics
     &   CO2aq                   , ! aqueous CO2, bulk concentration
     &   CO32m                   , ! carbonate (CO32-), bulk concentration
     &   hCO3m                   , ! bicarbonate (HCO3-), bulk concentration
     &   pH                      , ! pH, brine
     &   pCO2                      ! pCO2, brine

      COMMON/biocarbchem/       
     &   CO2aq                   , ! aqueous CO2, bulk concentration
     &   CO32m                   , ! carbonate (CO32-), bulk concentration
     &   hCO3m                   , ! bicarbonate (HCO3-), bulk concentration
     &   pH                      , ! pH, brine
     &   pCO2                      ! pCO2, brine

      CHARACTER(len=64) ::
     &   biotr_i_nam(ntra_bio_max)  , !:
     &   biotr_i_typ(ntra_bio_max)    !:

      CHARACTER(len=64) ::         
     &   biotr_i_uni(ntra_bio_max)

      CHARACTER(len=2) ::         
     &   c_grid

      CHARACTER(len=3) ::
     &   c_read_name(ntra_bio_max),
     &   c_nc_name(ntra_bio_max)
         
      COMMON /biochar/
     &   biotr_i_nam, 
     &   biotr_i_typ,
     &   biotr_i_uni,
     &   c_grid,
     &   c_read_name,
     &   c_nc_name   

      COMMON /biomass/
     &   chla_i_bio(nlay_bio)     !: chlorophyll a concentration

      REAL(8) ::
     &   ika_rate(nlay_bio)      , !: CaCO3 precipitation / dissolution rate (mmol/m3/s)
     &   ika_omega(nlay_bio)     , !: CACO3 saturation state (-)
     &   syn_bio(nlay_bio)       , !: synthesis
     &   lys_bio(nlay_bio)       , !: lysis
     &   exu_bio(nlay_bio)       , !: exudation
     &   rsp_bio(nlay_bio)       , !: respiration
     &   rem_bio(nlay_bio)       , !: remineralization
     &   lim_lig(nlay_bio)       , !: light limitation
     &   lim_dsi(nlay_bio)       , !: DSi limitation
     &   lim_no3(nlay_bio)       , !: NO3 limitation
     &   lim_po4(nlay_bio)       , !: PO4 limitation
     &   lim_tem(nlay_bio)       , !: temperature limitation
     &   lim_sal(nlay_bio)       , !: salt limitation
     &   chlC_bio(nlay_bio)        !: interactive chl-a / C ratio

      COMMON /biosources/
     &   ika_rate                , !: 
     &   ika_omega               , !: 
     &   syn_bio                 , !: 
     &   lys_bio                 , !: 
     &   exu_bio                 , !:
     &   rsp_bio                 , !: 
     &   rem_bio                 , !: 
     &   lim_lig                 , !:
     &   lim_dsi                 , !:
     &   lim_no3                 , !:
     &   lim_po4                 , !:
     &   lim_tem                 , !:
     &   lim_sal                 , !:
     &   chlC_bio                  !: 

      COMMON /biorad/             
     &   par_bio(nlay_bio)         !: Photosynthetically available radiation
                                   !: (flux micromol quanta m-2 s-1)
      !---------------------------------------
      ! Constants and parameters of the model
      !---------------------------------------
      REAL(8) ::
     &   mumax_bio               , !: maximum specific growth (s-1)
     &   klys_bio                , !: autolysis rate (s-1)
     &   ek_bio                  , !: light adaptation micrmol quanta m-2 s-1
     &   alpha_bio               , !: photosynthetic efficiency (gC/gchla/s-1/(muE/m2/s))
     &   khs_si_bio              , !: half sat for Si uptake (mmol m-3)
     &   khs_n_bio               , !: half sat for N uptake (mmol m-3)
     &   khs_p_bio               , !: half sat for P uptake (mmol m-3)
     &   frem_bio                , !: fraction of Si loss that is remineralized (-)
     &   krem_bio                , !: carbon remineralization time constant (s-1)
     &   krsp_bio                , !: carbon respiration time constant
     &   rg_bio                  , !: temperature coefficient for diatom synthesis (deg C-1)
     &   rg_bac                  , !: temperature coefficient for bacterial processes (deg C-1)
     &   lim_sal_wid             , !: width of the limitation function (case 4)
     &   lim_sal_smax            , !: salinity at which limitation function is 1 (case 4)
     &   chla_c                  , !: Chlorophyll-to-carbon ratio
     &   Estar                   , !: PAR level of minimum Chl/C
     &   si_c                    , !: Si cell quota in diatoms
     &   no3_c                   , !: N cell quota in diatoms
     &   po4_c                   , !: N cell quota in diatoms
     &   oxy_c                   , !: Oxygen cell quota in diatoms
     &   c_molar                   !: carbon molar mass

      COMMON /bioparams/
     &   mumax_bio, klys_bio, ek_bio, alpha_bio,
     &   khs_si_bio, khs_n_bio, khs_p_bio, frem_bio, 
     &   krem_bio, krsp_bio, 
     &   rg_bio, rg_bac, chla_c, Estar, si_c, no3_c, po4_c, oxy_c,
     &   lim_sal_wid, lim_sal_smax, c_molar

